=================
GSTools Tutorials
=================

In the following you will find several Tutorials on how to use GSTools to
explore its whole beauty and power.

.. toctree::
   :maxdepth: 1

   tutorial_01_srf.rst
   tutorial_02_cov.rst
   tutorial_03_vario.rst
   tutorial_04_vec_field.rst
   tutorial_05_kriging.rst
   tutorial_06_conditioning.rst
   tutorial_07_transformations.rst
